@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: Apache::SOAP.pm,v 0.47 2001/02/21 17:11:12 $
+# $Id: SOAP.pm,v 1.3 2001/08/11 19:09:57 paulk Exp $
 #
 # ======================================================================
 
@@ -15,19 +15,12 @@ use vars qw(@ISA $VERSION);
 use SOAP::Transport::HTTP;
 
 @ISA = qw(SOAP::Transport::HTTP::Apache);
-$VERSION = '0.47';
+$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name: release-0_55-public $ =~ /-(\d+)_([\d_]+)/);
 
-my $server = Apache::SOAP->new;
+my $server = __PACKAGE__->new;
 
 sub handler {
-  my $config = $_[0]->dir_config;
-  foreach (%$config) {
-    $config->{$_} =~ /=>/
-      ? $server->$_({split /\s*(?:=>|,)\s*/, $config->{$_}})
-      : ref $server->$_ ? 'hm, nothing can be done here'
-                        : $server->$_(split /\s+|\s*,\s*/, $config->{$_})
-      if $server->can($_);
-  }
+  $server->configure(@_);
   $server->SUPER::handler(@_);
 }
 
@@ -39,7 +32,7 @@ __END__
 
 =head1 NAME
 
-Apache::SOAP - Provide SOAP server functionality with simple configuration
+Apache::SOAP - mod_perl-based SOAP server with minimum configuration
 
 =head1 SYNOPSIS
 
