@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: Lite.pm 341 2009-09-30 18:34:58Z kutterma $
+# $Id: Lite.pm,v 1.3 2001/08/11 19:09:57 paulk Exp $
 #
 # ======================================================================
 
@@ -15,15 +15,10 @@ use vars qw(@ISA $VERSION);
 use XMLRPC::Transport::HTTP;
 
 @ISA = qw(XMLRPC::Transport::HTTP::Apache);
-
-use version; $VERSION = qv('0.710.10');
+$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name: release-0_55-public $ =~ /-(\d+)_([\d_]+)/);
 
 my $server = __PACKAGE__->new;
 
-sub server {
-    return $server;
-}
-
 sub handler {
   $server->configure(@_);
   $server->SUPER::handler(@_);
@@ -72,20 +67,20 @@ Apache::XMLRPC::Lite - mod_perl-based XML-RPC server with minimum configuration
 
 =head1 DESCRIPTION
 
-This Apache Perl module provides the ability to add support for XML-RPC
-protocol with easy configuration (either in .conf or in .htaccess file).
+This Apache Perl module provides the ability to add support for XML-RPC 
+protocol with easy configuration (either in .conf or in .htaccess file). 
 This functionality should give you lightweight option
 for hosting SOAP services and greatly simplify configuration aspects. This
 module inherites functionality from XMLRPC::Transport::HTTP::Apache component
 of XMLRPC::Lite module.
-
+ 
 =head1 CONFIGURATION
 
 The module can be placed in <Location>, <Directory>, <Files>, <FilesMatch>
 directives in main server configuration areas or directly in .htaccess file.
 
-All parameters should be quoted and can be separated with commas or spaces
-for lists ("a, b, c") and with 'wide arrows' and commas for hash parameters
+All parameters should be quoted and can be separated with commas or spaces 
+for lists ("a, b, c") and with 'wide arrows' and commas for hash parameters 
 ("key1 => value1, key2 => value2").
 
 All options that you can find in XMLRPC::Transport::HTTP::Apache component
@@ -96,35 +91,21 @@ ones.
 
 =item dispatch_to (LIST)
 
-Specifies path to directory that contains Perl modules you'd like to give
+Specifies path to directory that contains Perl modules you'd like to give 
 access to, or just list of modules (for preloaded modules).
 
   PerlSetVar dispatch_to "/Your/Path/To/Deployed/Modules, Module::Name, Module::method"
 
 =item options (HASH)
 
-Specifies list of options for your module, for example threshold for
-compression. Future versions will support more options. See
+Specifies list of options for your module, for example threshold for 
+compression. Future versions will support more options. See 
 XMLRPC::Transport::HTTP documentation for other options.
 
   PerlSetVar options "compress_threshold => 10000"
 
 =back
 
-=head1 METHODS/SUBROUTINES
-
-=head2 server
-
- my $server = Apache::XMLRPC::Lite->server();
-
-Returns the server object.
-
-Useful if you need to manipulate the server object from your code.
-
-=head2 handle
-
-Request handler. Called by apache.
-
 =head1 DEPENDENCIES
 
  XMLRPC::Lite
