@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: HTTP.pm 341 2009-09-30 18:34:58Z kutterma $
+# $Id: HTTP.pm,v 1.5 2001/10/14 18:11:27 paulk Exp $
 #
 # ======================================================================
 
@@ -12,9 +12,9 @@ package XMLRPC::Transport::HTTP;
 
 use strict;
 use vars qw($VERSION);
+$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name: release-0_55-public $ =~ /-(\d+)_([\d_]+)/);
 
-use XMLRPC::Lite; $VERSION = $XMLRPC::Lite::VERSION;
-
+use XMLRPC::Lite;
 use SOAP::Transport::HTTP;
 
 # ======================================================================
